# ifc4d

Ifc4D contains a series of utilities for converting to and from various 4D software. Currently supported:

 - Microsoft Project to IFC
 - Oracle Primavera 6 (P6) XML to IFC
 - Oracle Primavera 6 (P6) XER to IFC
 - Asta Powerproject to IFC
 - IFC to Oracle Primavera 6 (P6) XML
 - IFC to Microsoft Project

Planned (would you like to contribute? Please reach out!):

 - IFC to Oracle Primavera 6 (P6) XER
 - IFC to Oracle Primavera 6 (P6) XLS
 - IFC to Asta Powerproject
 - LibreProject to IFC
 - IFC to LibreProject
 - IFC to Gantt

## Useful links

 - [P6 EPPM XER Import/Export Data Map Guide](https://docs.oracle.com/cd/F12057_01/English/Mapping_and_Schema/xer_import_export_data_map_project/helpmain.htm?toc.htm?97881.htm)
 - [Microsoft Project 2007 XML XSD](https://schemas.microsoft.com/project/2007/mspdi_pj12.xsd)
 - [Microsoft Project XML Documentation](https://docs.microsoft.com/en-us/office-project/xml-data-interchange/project-xml-data-interchange-schema-reference?view=project-client-2016)
 - [Microsoft Project 2010 SDK Download](https://www.microsoft.com/en-us/download/details.aspx?id=15511) (needed to get `mspdi_pj14.xsd`)
